@@ -4,8 +4,8 @@
 %
 %    Copyright (C) 2013 SUPELEC
 %
-%    Authors:   Julien Bect       <julien.bect@supelec.fr>
-%               Emmanuel Vazquez  <emmanuel.vazquez@supelec.fr>
+%    Authors:   Julien Bect       <julien.bect@centralesupelec.fr>
+%               Emmanuel Vazquez  <emmanuel.vazquez@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -42,4 +42,4 @@ else
     s = [s sprintf('''%s''}', x.colnames{end})];
 end
 
-end % function stk_sprintf_colnames
+end % function
