@@ -4,7 +4,7 @@
 %
 %    Copyright (C) 2013 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -45,4 +45,4 @@ else % STK-style vectorization not supported => loop over the rows of x
     
 end
 
-end % function stk_parallel_feval
+end % function
