@@ -2,9 +2,10 @@
 
 % Copyright Notice
 %
+%    Copyright (C) 2017 CentraleSupelec
 %    Copyright (C) 2013 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -28,12 +29,37 @@
 
 function pareng = stk_parallel_engine_parfor()
 
-if matlabpool('size') > 0,
-    warning('A worker pool is already open.');
-else
-    matlabpool open;
+if exist ('parpool')
+    
+    try
+        parpool ();
+    catch
+        e = lasterror ();
+        if strfind (e.identifier, 'ConnectionOpen')
+            warning ('A worker pool is already open.');
+        else
+            rethrow (e);
+        end
+    end
+    
+else  % try the old syntax
+    
+    if matlabpool ('size') > 0
+        warning ('A worker pool is already open.');
+    else
+        matlabpool open;
+    end
+    
 end
 
-pareng = class(struct(), 'stk_parallel_engine_parfor');
+pareng = class (struct(), 'stk_parallel_engine_parfor');
 
-end % function stk_parallel_engine_parfor
+end % function
+
+%#ok<*DPOOL>
+
+
+%!test
+%! if exist ('matlabpool') || exist ('parpool')
+%!     stk_test_class ('stk_parallel_engine_parfor')
+%! end
